  // Importing the fields from D3
import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  format,
  line,
  area,
  curveBasis
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

// Loading and Parsing the CSV data for given URL
csv('https://gist.githubusercontent.com/srinivasaraosankula/fc2faa59bab45cbe40994c294bbd6ef2/raw/d5881bb36c6892d2ba423014dc321bbcbe692171/Profits%2520of%2520PWC%2520LLP.csv')
  .then(data => {
    data.forEach(d => {
      d.Profits = +d.Profits;

  // Procedure to retrieve the date format
      d.Year = d3.timeParse("%Y-%m-%d")(d.Year);
    });

  // Changing the values for showing on the areachart
const xAxisTickFormat = number =>
    format('.3s')(number)

const render = data => {
  
  // By Adding the X axis data  
  const xValue = d => d.Year;
  const xAxisLabel = 'Year';
  
  // By Adding the Y axis data  
  const yValue = d => d.Profits;
  const circleRadius = 9;
  const yAxisLabel = 'Profits';
  
  const margin = { top: 40, right: 22, bottom: 90, left: 130 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom; 
  
  // The range for X axis data is given
  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();
  
  // The range for Y axis data is given
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
    .nice();
  
  // Svg data is used for getting the Line Chart 
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
 
  // Giving the values to x-axis 
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(13);
  
  // Giving the values to y-axis  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(13)
    .tickFormat(xAxisTickFormat);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -93)
      .attr('x', -innerHeight / 2)
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 75)
      .attr('x', innerWidth / 2)
      .text(xAxisLabel);
 
  // We will be drawing the line to get a curve and then add to svg 
  const lineGenerator = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d)))
  	.curve(curveBasis);
 
  // We will be drawing area under the curve and then add to svg 
  const areaGenerator = area()
  	.x(d => xScale(xValue(d)))
  	.y0(innerHeight)
  	.y1(d => yScale(yValue(d)))
  	.curve(curveBasis);
  
  g.append('path')
  	.attr('class', 'line-chart')
  	.attr('d', lineGenerator(data));
  
  g.append('path')
  	.attr('class', 'area-chart')
  	.attr('d', areaGenerator(data));
  
 
};

  
    render(data);
  	console.log(data);
  });